#!/bin/sh

if [ "X$CIPHER_SUITE" = "X" ]
then
# Set cipher suite
CIPHER_SUITE="47"	#AES128-SHA
#CIPHER_SUITE="5"  	#RC4128-SHA
#CIPHER_SUITE="4"  	#RC4128-MD5
#CIPHER_SUITE="60" 	#AES128-SHA256
#CIPHER_SUITE="10"      #DES-CBC3-SHA
#CIPHER_SUITE="141"     #PSK_AES256-SHA
#CIPHER_SUITE="49156"  	#ECDH_ECDSA-AES128-SHA
#CIPHER_SUITE="49162"  	#ECDHE_ECDSA-AES256-SHA
#CIPHER_SUITE="156"     #RSA AES128-GCM-SHA256
#CIPHER_SUITE="157"     #RSA AES256-GCM-SHA384
#CIPHER_SUITE="57"  	#DHE_RSA AES256-SHA
#CIPHER_SUITE="49195"   #ECDHE_ECDSA-AES128-GCM-SHA256
#CIPHER_SUITE="49196"   #ECDHE_ECDSA-AES256-GCM-SHA384
#CIPHER_SUITE="52243"   #TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256
#CIPHER_SUITE="52244"   #TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256
fi
    
if [ "X$PROTOCOL_VERSION" = "X" ]
then
#PROTOCOL_VERSION="1"	#TLS1.0
#PROTOCOL_VERSION="2"	#TLS1.1
PROTOCOL_VERSION="3"	#TLS1.2
fi

IPADDR="127.0.0.1"
PORT="4433"
NEW_SESSIONS="1"
RESUMED_SESSIONS="0"
BYTES="1024"

#
#	HTTP GET ./index.html request for testing against any server
#
./client -s${IPADDR} -p${PORT} -u./index.html -n${NEW_SESSIONS} -r${RESUMED_SESSIONS} -V${PROTOCOL_VERSION} -c${CIPHER_SUITE} -d

#
#	Byte count request for testing against MatrixSSL sample server
#
#./client -s${IPADDR} -p${PORT} -b${BYTES} -n${NEW_SESSIONS} -r${RESUMED_SESSIONS} -V${PROTOCOL_VERSION} -c${CIPHER_SUITE} -d


